@@ -6,12 +6,12 @@
     <message>
         <location filename="../main.cpp" line="53"/>
         <source>Unable to get exclusive lock</source>
-        <translation type="unfinished"></translation>
+        <translation>Egy másik csomagkezelő alkalmazás - a Synaptic, vagy az apt-get - már fut. Kérem zárja be először ezt az alkalmazást!</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="54"/>
         <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
-        <translation type="unfinished"></translation>
+        <translation>Egy másik csomagkezelő alkalmazás (vagy a Synaptic, vagy az apt-get) már fut. Kérem zárja be először ezt az alkalmazást!</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="67"/>
@@ -43,7 +43,7 @@
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="97"/>
-        <location filename="../mxcodecs.cpp" line="270"/>
+        <location filename="../mxcodecs.cpp" line="267"/>
         <source>Cancel</source>
         <translation>Mégsem</translation>
     </message>
@@ -93,140 +93,141 @@
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="103"/>
-        <location filename="../mxcodecs.cpp" line="110"/>
-        <location filename="../mxcodecs.cpp" line="118"/>
-        <location filename="../mxcodecs.cpp" line="126"/>
-        <location filename="../mxcodecs.cpp" line="135"/>
-        <location filename="../mxcodecs.cpp" line="142"/>
-        <location filename="../mxcodecs.cpp" line="151"/>
-        <location filename="../mxcodecs.cpp" line="159"/>
+        <location filename="../mxcodecs.cpp" line="104"/>
+        <location filename="../mxcodecs.cpp" line="111"/>
+        <location filename="../mxcodecs.cpp" line="119"/>
+        <location filename="../mxcodecs.cpp" line="127"/>
+        <location filename="../mxcodecs.cpp" line="136"/>
+        <location filename="../mxcodecs.cpp" line="143"/>
+        <location filename="../mxcodecs.cpp" line="152"/>
+        <location filename="../mxcodecs.cpp" line="160"/>
         <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
         <translation>&lt;b&gt;Parancs futtatása...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="106"/>
-        <location filename="../mxcodecs.cpp" line="122"/>
-        <location filename="../mxcodecs.cpp" line="129"/>
-        <location filename="../mxcodecs.cpp" line="138"/>
-        <location filename="../mxcodecs.cpp" line="144"/>
-        <location filename="../mxcodecs.cpp" line="155"/>
-        <location filename="../mxcodecs.cpp" line="162"/>
-        <location filename="../mxcodecs.cpp" line="194"/>
-        <location filename="../mxcodecs.cpp" line="247"/>
+        <location filename="../mxcodecs.cpp" line="107"/>
+        <location filename="../mxcodecs.cpp" line="123"/>
+        <location filename="../mxcodecs.cpp" line="130"/>
+        <location filename="../mxcodecs.cpp" line="139"/>
+        <location filename="../mxcodecs.cpp" line="145"/>
+        <location filename="../mxcodecs.cpp" line="156"/>
+        <location filename="../mxcodecs.cpp" line="163"/>
+        <location filename="../mxcodecs.cpp" line="192"/>
+        <location filename="../mxcodecs.cpp" line="245"/>
         <source>Error</source>
         <translation>Hiba</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="107"/>
-        <location filename="../mxcodecs.cpp" line="123"/>
-        <location filename="../mxcodecs.cpp" line="139"/>
-        <location filename="../mxcodecs.cpp" line="156"/>
+        <location filename="../mxcodecs.cpp" line="108"/>
+        <location filename="../mxcodecs.cpp" line="124"/>
+        <location filename="../mxcodecs.cpp" line="140"/>
+        <location filename="../mxcodecs.cpp" line="157"/>
         <source>Cannot connect to the download site</source>
         <translation>Nem sikerült a csatlakozás a letöltőoldalhoz</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="113"/>
-        <location filename="../mxcodecs.cpp" line="130"/>
-        <location filename="../mxcodecs.cpp" line="145"/>
-        <location filename="../mxcodecs.cpp" line="163"/>
+        <location filename="../mxcodecs.cpp" line="114"/>
+        <location filename="../mxcodecs.cpp" line="131"/>
+        <location filename="../mxcodecs.cpp" line="146"/>
+        <location filename="../mxcodecs.cpp" line="164"/>
         <source>Error downloading %1</source>
         <translation>Hibás letöltés %1</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="168"/>
+        <location filename="../mxcodecs.cpp" line="169"/>
         <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
         <translation>&lt;b&gt;A letöltés kész.&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="190"/>
+        <location filename="../mxcodecs.cpp" line="188"/>
         <source>Installing downloaded files</source>
         <translation>Letöltött fájlok telepítése</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="195"/>
+        <location filename="../mxcodecs.cpp" line="193"/>
         <source>No downloaded *.debs files found.</source>
         <translation>A letöltött *.deb fájlok nem találhatóak.</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="208"/>
+        <location filename="../mxcodecs.cpp" line="206"/>
         <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
         <translation>&lt;b&gt;Telepítés...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="222"/>
+        <location filename="../mxcodecs.cpp" line="219"/>
         <source>Error installing %1</source>
         <translation>Hibás telepítés %1</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="226"/>
+        <location filename="../mxcodecs.cpp" line="223"/>
         <source>Fix missing dependencies...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="228"/>
-        <source>Error running &apos;apt-get -fm install&apos; command</source>
+        <location filename="../mxcodecs.cpp" line="225"/>
+        <source>Error running %1 command</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="240"/>
+        <location filename="../mxcodecs.cpp" line="237"/>
         <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
         <translation>&lt;b&gt;A telepítési folyamat kész&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="243"/>
+        <location filename="../mxcodecs.cpp" line="241"/>
         <source>Finished</source>
         <translation>Kész</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="244"/>
+        <location filename="../mxcodecs.cpp" line="242"/>
         <source>Codecs files have been downloaded and installed successfully.</source>
         <translation>Kodekfájlok sikeresen letöltve és telepítve.</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="248"/>
+        <location filename="../mxcodecs.cpp" line="246"/>
         <source>Process finished. Errors have occurred during the installation.</source>
         <translation>A folyamat kész. Hibák történtek a telepítés során.</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="263"/>
+        <location filename="../mxcodecs.cpp" line="260"/>
         <source>About MX Codecs</source>
         <translation>Az MX kodektelepítőről</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="264"/>
+        <location filename="../mxcodecs.cpp" line="261"/>
         <source>MX Codecs</source>
         <translation>MX kodektelepítő</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="264"/>
+        <location filename="../mxcodecs.cpp" line="261"/>
         <source>Version: </source>
         <translation>Verzió:</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="266"/>
+        <location filename="../mxcodecs.cpp" line="263"/>
         <source>Simple codecs downloader for MX Linux</source>
         <translation>Egyszerű kodekletöltő MX Linuxhoz</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="267"/>
+        <location filename="../mxcodecs.cpp" line="264"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="268"/>
+        <location filename="../mxcodecs.cpp" line="265"/>
         <source>License</source>
         <translation>Liszensz</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="269"/>
+        <location filename="../mxcodecs.cpp" line="266"/>
+        <location filename="../mxcodecs.cpp" line="276"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Változásbejegyzés</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="285"/>
+        <location filename="../mxcodecs.cpp" line="283"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Bezár</translation>
     </message>
 </context>
 </TS>
