@@ -6,7 +6,7 @@
     <message>
         <location filename="../main.cpp" line="53"/>
         <source>Unable to get exclusive lock</source>
-        <translation>Non si riesce ad ottenere un controllo esclusivo</translation>
+        <translation>Impossibile ottenere il blocco esclusivo</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="54"/>
@@ -25,26 +25,26 @@ Prego, chiudi prima quell&apos;applicazione.</translation>
     <message>
         <location filename="../mxcodecs.ui" line="14"/>
         <source>MX Codecs Installer</source>
-        <translation>MX Installa Codecs</translation>
+        <translation>Installatore di MX Codec</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="27"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Questa applicazione ti permette di installare codecs proprietari che supportano funzioni avanzate audio e video.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In alcune giurisdizioni la loro distribuzione potrebbe avere delle restrizioni, per cui l&apos;utente deve tener conto della propria regolamentazione locale. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ti assumi la responsabilità legale di scaricare questi codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Questa applicazione ti permette di installare codec proprietari che consentono funzioni audio e video avanzate.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In alcune giurisdizioni la loro distribuzione potrebbe avere delle restrizioni, per cui l&apos;utente deve tener conto delle regolamentazioni locali. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ti assumi la responsabilità legale di scaricare questi codec?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="44"/>
         <source>Downloading codecs files</source>
-        <translation>Downloading codecs</translation>
+        <translation>Scaricamento dei codec</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="94"/>
         <source>Cancel any changes then quit</source>
-        <translation>Cancella tutte le modifiche quando chiudi</translation>
+        <translation>Cancella tutte le modifiche ed esci</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="97"/>
-        <location filename="../mxcodecs.cpp" line="270"/>
+        <location filename="../mxcodecs.cpp" line="267"/>
         <source>Cancel</source>
         <translation>Annulla</translation>
     </message>
@@ -56,7 +56,7 @@ Prego, chiudi prima quell&apos;applicazione.</translation>
     <message>
         <location filename="../mxcodecs.ui" line="118"/>
         <source>Apply any changes then quit</source>
-        <translation>Applica tutte le modifiche quando chiudi</translation>
+        <translation>Applica tutte le modifiche ed esci</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="121"/>
@@ -94,138 +94,139 @@ Prego, chiudi prima quell&apos;applicazione.</translation>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="103"/>
-        <location filename="../mxcodecs.cpp" line="110"/>
-        <location filename="../mxcodecs.cpp" line="118"/>
-        <location filename="../mxcodecs.cpp" line="126"/>
-        <location filename="../mxcodecs.cpp" line="135"/>
-        <location filename="../mxcodecs.cpp" line="142"/>
-        <location filename="../mxcodecs.cpp" line="151"/>
-        <location filename="../mxcodecs.cpp" line="159"/>
+        <location filename="../mxcodecs.cpp" line="104"/>
+        <location filename="../mxcodecs.cpp" line="111"/>
+        <location filename="../mxcodecs.cpp" line="119"/>
+        <location filename="../mxcodecs.cpp" line="127"/>
+        <location filename="../mxcodecs.cpp" line="136"/>
+        <location filename="../mxcodecs.cpp" line="143"/>
+        <location filename="../mxcodecs.cpp" line="152"/>
+        <location filename="../mxcodecs.cpp" line="160"/>
         <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
-        <translation>&lt;b&gt;Esecuzione comando...&lt;/b&gt;&lt;p&gt;</translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="106"/>
-        <location filename="../mxcodecs.cpp" line="122"/>
-        <location filename="../mxcodecs.cpp" line="129"/>
-        <location filename="../mxcodecs.cpp" line="138"/>
-        <location filename="../mxcodecs.cpp" line="144"/>
-        <location filename="../mxcodecs.cpp" line="155"/>
-        <location filename="../mxcodecs.cpp" line="162"/>
-        <location filename="../mxcodecs.cpp" line="194"/>
-        <location filename="../mxcodecs.cpp" line="247"/>
-        <source>Error</source>
-        <translation>Errore</translation>
+        <translation>&lt;b&gt;Comando in esecuzione...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
         <location filename="../mxcodecs.cpp" line="107"/>
         <location filename="../mxcodecs.cpp" line="123"/>
-        <location filename="../mxcodecs.cpp" line="139"/>
-        <location filename="../mxcodecs.cpp" line="156"/>
-        <source>Cannot connect to the download site</source>
-        <translation>Connessione al sito del download non riuscita</translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="113"/>
         <location filename="../mxcodecs.cpp" line="130"/>
+        <location filename="../mxcodecs.cpp" line="139"/>
         <location filename="../mxcodecs.cpp" line="145"/>
+        <location filename="../mxcodecs.cpp" line="156"/>
         <location filename="../mxcodecs.cpp" line="163"/>
+        <location filename="../mxcodecs.cpp" line="192"/>
+        <location filename="../mxcodecs.cpp" line="245"/>
+        <source>Error</source>
+        <translation>Errore</translation>
+    </message>
+    <message>
+        <location filename="../mxcodecs.cpp" line="108"/>
+        <location filename="../mxcodecs.cpp" line="124"/>
+        <location filename="../mxcodecs.cpp" line="140"/>
+        <location filename="../mxcodecs.cpp" line="157"/>
+        <source>Cannot connect to the download site</source>
+        <translation>Non posso connettermi al sito dello scaricamento</translation>
+    </message>
+    <message>
+        <location filename="../mxcodecs.cpp" line="114"/>
+        <location filename="../mxcodecs.cpp" line="131"/>
+        <location filename="../mxcodecs.cpp" line="146"/>
+        <location filename="../mxcodecs.cpp" line="164"/>
         <source>Error downloading %1</source>
-        <translation>Errore di download %1</translation>
+        <translation>Errore di scaricamento %1</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="168"/>
+        <location filename="../mxcodecs.cpp" line="169"/>
         <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Download Finito.&lt;/b&gt;</translation>
+        <translation>&lt;b&gt;Scaricamento finito.&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="190"/>
+        <location filename="../mxcodecs.cpp" line="188"/>
         <source>Installing downloaded files</source>
         <translation>Installazione file scaricati</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="195"/>
+        <location filename="../mxcodecs.cpp" line="193"/>
         <source>No downloaded *.debs files found.</source>
-        <translation>Trovato  file *.debs non scaricato.</translation>
+        <translation>Nessun file *.debs scaricato trovato</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="208"/>
+        <location filename="../mxcodecs.cpp" line="206"/>
         <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
         <translation>&lt;b&gt;Installazione...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="222"/>
+        <location filename="../mxcodecs.cpp" line="219"/>
         <source>Error installing %1</source>
         <translation>Errore di installazione %1</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="226"/>
+        <location filename="../mxcodecs.cpp" line="223"/>
         <source>Fix missing dependencies...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="228"/>
-        <source>Error running &apos;apt-get -fm install&apos; command</source>
+        <location filename="../mxcodecs.cpp" line="225"/>
+        <source>Error running %1 command</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="240"/>
+        <location filename="../mxcodecs.cpp" line="237"/>
         <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Processo di installazione terminato&lt;/b&gt;</translation>
+        <translation>&lt;b&gt;Il processo d&apos;installazione è terminato&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="243"/>
+        <location filename="../mxcodecs.cpp" line="241"/>
         <source>Finished</source>
         <translation>Finito</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="244"/>
+        <location filename="../mxcodecs.cpp" line="242"/>
         <source>Codecs files have been downloaded and installed successfully.</source>
-        <translation>I Codecs sono stati scaricati e installati con successo.</translation>
+        <translation>I codec sono stati scaricati e installati con successo.</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="248"/>
+        <location filename="../mxcodecs.cpp" line="246"/>
         <source>Process finished. Errors have occurred during the installation.</source>
         <translation>Processo finito. Sono avvenuti degli errori durante l&apos;installazione.</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="263"/>
+        <location filename="../mxcodecs.cpp" line="260"/>
         <source>About MX Codecs</source>
         <translation>Informazioni su MX Codecs</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="264"/>
+        <location filename="../mxcodecs.cpp" line="261"/>
         <source>MX Codecs</source>
         <translation>MX Codecs</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="264"/>
+        <location filename="../mxcodecs.cpp" line="261"/>
         <source>Version: </source>
         <translation>Versione:</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="266"/>
+        <location filename="../mxcodecs.cpp" line="263"/>
         <source>Simple codecs downloader for MX Linux</source>
-        <translation>Semplice downloader di codecs per MX Linux</translation>
+        <translation>Semplice scaricatore di codec per MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="267"/>
+        <location filename="../mxcodecs.cpp" line="264"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="268"/>
+        <location filename="../mxcodecs.cpp" line="265"/>
         <source>License</source>
         <translation>Licenza</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="269"/>
+        <location filename="../mxcodecs.cpp" line="266"/>
+        <location filename="../mxcodecs.cpp" line="276"/>
         <source>Changelog</source>
-        <translation>Changelog</translation>
+        <translation>Registro delle modifiche</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="285"/>
+        <location filename="../mxcodecs.cpp" line="283"/>
         <source>&amp;Close</source>
         <translation>&amp;Chiudi</translation>
     </message>
