@@ -6,17 +6,17 @@
     <message>
         <location filename="../main.cpp" line="53"/>
         <source>Unable to get exclusive lock</source>
-        <translation type="unfinished"></translation>
+        <translation>Ekskluzivni zaklep ni mogoč</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="54"/>
         <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
-        <translation type="unfinished"></translation>
+        <translation>Zagnana je še ena aplikacija za nameščanje programov (kot sta Synaptic ali apt-get). Zaprite najprej to aplikacijo</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="67"/>
         <source>You must run this program as root.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ta program morate zagnati kot root</translation>
     </message>
 </context>
 <context>
@@ -24,38 +24,38 @@
     <message>
         <location filename="../mxcodecs.ui" line="14"/>
         <source>MX Codecs Installer</source>
-        <translation type="unfinished"></translation>
+        <translation>Namestitveni program za MX kodeke</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="27"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Ta aplikacija omogoča namestitev avtorsko zaščitenih kodekov, ki omogočajo napredne funkcije za video in zvok.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;Nekatare zakoodaje omejujejo njihovo distribucijo, zato naj uporabnik upošteva lokalne omejitve. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ali razumete pravno odgovornnost, ki izhaja iz prenosa teh kodekov?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="44"/>
         <source>Downloading codecs files</source>
-        <translation type="unfinished"></translation>
+        <translation>Prenos kodekov</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="94"/>
         <source>Cancel any changes then quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Zavrzi vse spremembe in končaj</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="97"/>
-        <location filename="../mxcodecs.cpp" line="270"/>
+        <location filename="../mxcodecs.cpp" line="267"/>
         <source>Cancel</source>
         <translation>Prekini</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="105"/>
         <source>Alt+N</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="118"/>
         <source>Apply any changes then quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Potrdi spremembe in končaj</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="121"/>
@@ -65,22 +65,22 @@
     <message>
         <location filename="../mxcodecs.ui" line="177"/>
         <source>About this application</source>
-        <translation type="unfinished"></translation>
+        <translation>O tem programu</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="180"/>
         <source>About...</source>
-        <translation type="unfinished"></translation>
+        <translation>O programu...</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="188"/>
         <source>Alt+B</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="217"/>
         <source>Display help </source>
-        <translation type="unfinished"></translation>
+        <translation>Prikaži pomoč</translation>
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="220"/>
@@ -90,143 +90,144 @@
     <message>
         <location filename="../mxcodecs.ui" line="228"/>
         <source>Alt+H</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="103"/>
-        <location filename="../mxcodecs.cpp" line="110"/>
-        <location filename="../mxcodecs.cpp" line="118"/>
-        <location filename="../mxcodecs.cpp" line="126"/>
-        <location filename="../mxcodecs.cpp" line="135"/>
-        <location filename="../mxcodecs.cpp" line="142"/>
-        <location filename="../mxcodecs.cpp" line="151"/>
-        <location filename="../mxcodecs.cpp" line="159"/>
+        <location filename="../mxcodecs.cpp" line="104"/>
+        <location filename="../mxcodecs.cpp" line="111"/>
+        <location filename="../mxcodecs.cpp" line="119"/>
+        <location filename="../mxcodecs.cpp" line="127"/>
+        <location filename="../mxcodecs.cpp" line="136"/>
+        <location filename="../mxcodecs.cpp" line="143"/>
+        <location filename="../mxcodecs.cpp" line="152"/>
+        <location filename="../mxcodecs.cpp" line="160"/>
         <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="106"/>
-        <location filename="../mxcodecs.cpp" line="122"/>
-        <location filename="../mxcodecs.cpp" line="129"/>
-        <location filename="../mxcodecs.cpp" line="138"/>
-        <location filename="../mxcodecs.cpp" line="144"/>
-        <location filename="../mxcodecs.cpp" line="155"/>
-        <location filename="../mxcodecs.cpp" line="162"/>
-        <location filename="../mxcodecs.cpp" line="194"/>
-        <location filename="../mxcodecs.cpp" line="247"/>
-        <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Izvajanje ukaza...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
         <location filename="../mxcodecs.cpp" line="107"/>
         <location filename="../mxcodecs.cpp" line="123"/>
-        <location filename="../mxcodecs.cpp" line="139"/>
-        <location filename="../mxcodecs.cpp" line="156"/>
-        <source>Cannot connect to the download site</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="113"/>
         <location filename="../mxcodecs.cpp" line="130"/>
+        <location filename="../mxcodecs.cpp" line="139"/>
         <location filename="../mxcodecs.cpp" line="145"/>
+        <location filename="../mxcodecs.cpp" line="156"/>
         <location filename="../mxcodecs.cpp" line="163"/>
+        <location filename="../mxcodecs.cpp" line="192"/>
+        <location filename="../mxcodecs.cpp" line="245"/>
+        <source>Error</source>
+        <translation>Napaka</translation>
+    </message>
+    <message>
+        <location filename="../mxcodecs.cpp" line="108"/>
+        <location filename="../mxcodecs.cpp" line="124"/>
+        <location filename="../mxcodecs.cpp" line="140"/>
+        <location filename="../mxcodecs.cpp" line="157"/>
+        <source>Cannot connect to the download site</source>
+        <translation>Ne morem se povezati s stranjo za prenos</translation>
+    </message>
+    <message>
+        <location filename="../mxcodecs.cpp" line="114"/>
+        <location filename="../mxcodecs.cpp" line="131"/>
+        <location filename="../mxcodecs.cpp" line="146"/>
+        <location filename="../mxcodecs.cpp" line="164"/>
         <source>Error downloading %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Napaka pri prenašanju %1</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="168"/>
+        <location filename="../mxcodecs.cpp" line="169"/>
         <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Prenos je končan.&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="190"/>
+        <location filename="../mxcodecs.cpp" line="188"/>
         <source>Installing downloaded files</source>
-        <translation type="unfinished"></translation>
+        <translation>Nameščanje prenešenih datotek</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="195"/>
+        <location filename="../mxcodecs.cpp" line="193"/>
         <source>No downloaded *.debs files found.</source>
-        <translation type="unfinished"></translation>
+        <translation>Prenešenih .deb datotek ni bilo mogoče najti.</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="208"/>
+        <location filename="../mxcodecs.cpp" line="206"/>
         <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Nameščanje...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="222"/>
+        <location filename="../mxcodecs.cpp" line="219"/>
         <source>Error installing %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Napaka pri nameščanju %1</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="226"/>
+        <location filename="../mxcodecs.cpp" line="223"/>
         <source>Fix missing dependencies...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="228"/>
-        <source>Error running &apos;apt-get -fm install&apos; command</source>
+        <location filename="../mxcodecs.cpp" line="225"/>
+        <source>Error running %1 command</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="240"/>
+        <location filename="../mxcodecs.cpp" line="237"/>
         <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Proces nameščanja je končan&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="243"/>
+        <location filename="../mxcodecs.cpp" line="241"/>
         <source>Finished</source>
-        <translation type="unfinished"></translation>
+        <translation>Končano</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="244"/>
+        <location filename="../mxcodecs.cpp" line="242"/>
         <source>Codecs files have been downloaded and installed successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation>Kodeki so bili uspešno prenešeni in nameščeni.</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="248"/>
+        <location filename="../mxcodecs.cpp" line="246"/>
         <source>Process finished. Errors have occurred during the installation.</source>
-        <translation type="unfinished"></translation>
+        <translation>Postopek je končan. Pri namestitvi so se pojavile napake.</translation>
+    </message>
+    <message>
+        <location filename="../mxcodecs.cpp" line="260"/>
+        <source>About MX Codecs</source>
+        <translation>O MX kodekih</translation>
+    </message>
+    <message>
+        <location filename="../mxcodecs.cpp" line="261"/>
+        <source>MX Codecs</source>
+        <translation>MX kodeki</translation>
+    </message>
+    <message>
+        <location filename="../mxcodecs.cpp" line="261"/>
+        <source>Version: </source>
+        <translation>Različica:</translation>
     </message>
     <message>
         <location filename="../mxcodecs.cpp" line="263"/>
-        <source>About MX Codecs</source>
-        <translation type="unfinished"></translation>
+        <source>Simple codecs downloader for MX Linux</source>
+        <translation>Enostaven prenos kodekov za MX Linux</translation>
     </message>
     <message>
         <location filename="../mxcodecs.cpp" line="264"/>
-        <source>MX Codecs</source>
-        <translation type="unfinished"></translation>
+        <source>Copyright (c) MX Linux</source>
+        <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="264"/>
-        <source>Version: </source>
-        <translation type="unfinished"></translation>
+        <location filename="../mxcodecs.cpp" line="265"/>
+        <source>License</source>
+        <translation>Licenca</translation>
     </message>
     <message>
         <location filename="../mxcodecs.cpp" line="266"/>
-        <source>Simple codecs downloader for MX Linux</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="267"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="268"/>
-        <source>License</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="269"/>
+        <location filename="../mxcodecs.cpp" line="276"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Dnevnik sprememb</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="285"/>
+        <location filename="../mxcodecs.cpp" line="283"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Zapri</translation>
     </message>
 </context>
 </TS>
